@@ -193,8 +193,6 @@ class Assets(WMLResource):
         desc = description
         if desc is None:
             desc = ""
-        if connection_id is None:
-            f = {'file': open(file_path, 'rb')}
         try:
             import mimetypes
         except Exception as e:
@@ -291,19 +289,18 @@ class Assets(WMLResource):
                         attachment_id = attachment_details["attachment_id"]
                         attachment_url = attachment_details["url1"]
                         #Step3: Put content to attachment
-                        if not self._ICP:
-                                files = open(file_path, 'rb')
-
-                                put_response = requests.put(
-                                    attachment_url,
-                                    data=files.read()
-                                )
-                        else:
-                                put_response = requests.put(
-                                    self._wml_credentials['url'] + attachment_url,
-                                    files=f,
-                                    verify=False
-                                )
+                        with open(file_path, 'rb') as _file:
+                            if not self._ICP:
+                                    put_response = requests.put(
+                                        attachment_url,
+                                        data=_file
+                                    )
+                            else:
+                                    put_response = requests.put(
+                                        self._wml_credentials['url'] + attachment_url,
+                                        files={'file': _file},
+                                        verify=False
+                                    )
                         if put_response.status_code == 201 or put_response.status_code == 200:
                             # Step4: Complete attachment
                             if not self._ICP:
