@@ -14,6 +14,8 @@
 
 from __future__ import print_function
 import requests
+
+from ibm_watson_machine_learning.messages.messages import Messages
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ConnectionMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -102,7 +104,7 @@ class Connections(WMLResource):
 
             return new_el
         except Exception as e:
-            raise WMLClientError("Failed to read Response from down-stream service: " + response_data)
+            raise WMLClientError(Messages.get_message(response_data, message_id="failed_to_read_response_from_down_stream_service"))
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, connection_id=None):
@@ -267,7 +269,7 @@ class Connections(WMLResource):
 
         connection_meta.update({'origin_country': 'US'})
         #Step1  : Create an asset
-        print("Creating connections...")
+        print(Messages.get_message(message_id="creating_connections"))
 
         if self._client.WSD:
             header_param = self._client._get_headers(wsdconnection_api_req=True)
@@ -292,10 +294,10 @@ class Connections(WMLResource):
         connection_details = self._handle_response(201, u'creating new connection', creation_response)
         if creation_response.status_code == 201:
             connection_id = connection_details["metadata"]["asset_id"]
-            print("SUCCESS")
+            print(Messages.get_message(message_id="success"))
             return self._get_required_element_from_response(connection_details)
         else:
-            raise WMLClientError("Failed while creating a Connections. Try again.")
+            raise WMLClientError(Messages.get_message(message_id="failed_while_creating_connections"))
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, connection_id):
