@@ -30,6 +30,7 @@ from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto
                                   download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn)
 from ..utils.deployment.errors import (WrongDeploymnetType, ModelTypeNotSupported, NotAutoAIExperiment,
                                        DeploymentNotSupported, MissingSpace, ModelPromotionFailed)
+from ..helpers import DataConnection
 from ..wml_client_error import ApiRequestFailure
 from ..workspace import WorkSpace
 
@@ -65,18 +66,18 @@ class BaseDeployment(ABC):
         # note: backward compatibility
         if wml_credentials is not None:
             source_wml_credentials = wml_credentials
-            warn("\"wml_credentials\" parameter is depreciated, please use \"source_wml_credentials\"")
-            print("\"wml_credentials\" parameter is depreciated, please use \"source_wml_credentials\"")
+            warn("\"wml_credentials\" parameter is deprecated, please use \"source_wml_credentials\"")
+            print("\"wml_credentials\" parameter is deprecated, please use \"source_wml_credentials\"")
 
         if project_id is not None:
             source_project_id = project_id
-            warn("\"project_id\" parameter is depreciated, please use \"source_project_id\"")
-            print("\"project_id\" parameter is depreciated, please use \"source_project_id\"")
+            warn("\"project_id\" parameter is deprecated, please use \"source_project_id\"")
+            print("\"project_id\" parameter is deprecated, please use \"source_project_id\"")
 
         if space_id is not None:
             source_space_id = space_id
-            warn("\"space_id\" parameter is depreciated, please use \"source_space_id\"")
-            print("\"space_id\" parameter is depreciated, please use \"source_space_id\"")
+            warn("\"space_id\" parameter is deprecated, please use \"source_space_id\"")
+            print("\"space_id\" parameter is deprecated, please use \"source_space_id\"")
         # --- end note
 
         # note: as workspace is not clear enough to understand, there is a possibility to use pure
@@ -226,12 +227,22 @@ class BaseDeployment(ABC):
                     schema['schemas'] if self._obm else [schema])
 
             else:
+
+                # Note: We need to fetch credentials when 'container' is the type
+                if run_params['entity']['results_reference']['type'] == 'container':
+                    data_connection = DataConnection._from_dict(_dict=run_params['entity']['results_reference'])
+                    data_connection._wml_client = self._source_workspace.wml_client
+                else:
+                    data_connection = None
+                # --- end note
+
                 artifact_name, model_props = prepare_auto_ai_model_to_publish_normal_scenario(
                     pipeline_model=model,
                     run_params=run_params,
                     run_id=kwargs['experiment_run_id'],
                     wml_client=self._source_workspace.wml_client,
-                    space_id=self._target_workspace.space_id
+                    space_id=self._target_workspace.space_id,
+                    result_reference=data_connection
                 )
 
             deployment_details = self._deploy(
@@ -268,7 +279,8 @@ class BaseDeployment(ABC):
 
                 # note: CLOUD
                 else:
-                    optimizer = AutoAI().runs.get_optimizer(metadata=kwargs['metadata'])
+                    optimizer = AutoAI().runs.get_optimizer(metadata=kwargs['metadata'],
+                                                            wml_client=self._source_workspace.wml_client)
 
                 # note: check for obm step in pipeline details
                 if hasattr(optimizer, '_result_client'):
