@@ -481,8 +481,7 @@ class Batch(BaseDeployment):
                     if conn.type == DataConnectionTypes.S3:
                         conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
 
-                    elif (conn.type == DataConnectionTypes.CA and
-                          (os.environ.get('USER_ACCESS_TOKEN') is None and conn._check_if_connection_asset_is_s3())):
+                    elif conn.type == DataConnectionTypes.CA and conn._check_if_connection_asset_is_s3():
                         conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
 
                 return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
