@@ -438,18 +438,16 @@ class Deployments(WMLResource):
                     )
                 return self._handle_response(200, "deployment", response)
             else:
-                query_params = None
-                if serving_name:
-                    query_params = {
-                        'serving_name': serving_name
-                    }
-                deployment_details = self._get_artifact_details(url, deployment_uid, limit,
-                                                                'deployments', query_params=query_params)
+                deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments')
                 if "system" in deployment_details:
                     print("Note: " + deployment_details['system']['warnings'][0]['message'])
                 return deployment_details
         else:
-            details = self._get_artifact_details(url, deployment_uid, limit, 'deployments')
+            query_params = self._client._params()
+            if serving_name:
+                query_params['serving_name'] = serving_name
+
+            details = self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
             
             return details
 
@@ -527,7 +525,7 @@ class Deployments(WMLResource):
 
         try:
             serving_name = deployment_details['entity']['online'].get('parameters').get('serving_name')
-            serving_url = deployment_details['entity']['serving_endpoints'].get(serving_name)
+            serving_url = [url for url in deployment_details['entity'].get('status').get('serving_urls') if serving_name == url.split('/')[-2]][0]
 
             if serving_url:
                 return serving_url
@@ -1074,16 +1072,43 @@ class Deployments(WMLResource):
             raise WMLClientError(msg)
 
         # if changes.get('asset') is not None and (changes.get('name') is not None or changes.get('description') is not None):
-        if changes.get('asset') is not None and (len(changes) > 1):
-            msg = "When ASSET is being updated/patched, other fields cannot be updated. If other fields are to be " \
-                  "updated, try without ASSET update. ASSET update triggers deployment with the new asset retaining " \
+        patch_job = changes.get('asset') is not None or self.ConfigurationMetaNames.SERVING_NAME in changes or self.ConfigurationMetaNames.OWNER in changes
+
+        patch_job_field = None
+        if patch_job:
+            if changes.get('asset') is not None:
+                patch_job_field = "ASSET"
+            elif self.ConfigurationMetaNames.SERVING_NAME in changes:
+                patch_job_field = "SERVING_NAME"
+            elif self.ConfigurationMetaNames.OWNER in changes:
+                patch_job_field = "OWNER"
+
+            if patch_job_field is None:
+                raise WMLClientError("Unexpected patch job element.")
+
+        if patch_job and (len(changes) > 1):
+            msg = f"When {patch_job_field} is being updated/patched, other fields cannot be updated. If other fields are to be " \
+                  f"updated, try without {patch_job_field} update. {patch_job_field} update triggers deployment with the new asset retaining " \
                   "the same deployment_id"
             print(msg)
             raise WMLClientError(msg)
 
         deployment_details = self.get_details(deployment_uid)
+        serving_name_change = False
+        new_serving_name = None
+        if self.ConfigurationMetaNames.SERVING_NAME in changes:
+            new_serving_name = changes.pop(self.ConfigurationMetaNames.SERVING_NAME)
+            serving_name_change = True
+
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(deployment_details, changes, with_validation=True)
 
+        if serving_name_change:
+            replace = 'serving_name' in deployment_details['entity'].get('online').get('parameters', [])
+            patch_payload.append({
+                "op": "replace" if replace else "add",
+                "path": "/online/parameters",
+                "value": {"serving_name": new_serving_name}})
+
         ## As auto_online_deployment and auto_redeploy values are passed as 'bool' but service needs them in 'str' format to patch.
         for ele in patch_payload:
             if('auto_online_deployment' in ele['path'] or 'auto_redeploy' in ele['path']):
@@ -1095,18 +1120,18 @@ class Deployments(WMLResource):
         url = self._client.service_instance._href_definitions.get_deployment_href(deployment_uid)
 
         if not self._ICP:
-            response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers())
+            response = requests.patch(url, json=patch_payload, params=self._client._params(), headers=self._client._get_headers())
         else:
-            response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers(), verify=False)
+            response = requests.patch(url, json=patch_payload, params=self._client._params(), headers=self._client._get_headers(), verify=False)
 
-        if 'asset' in changes and response.status_code == 202:
+        if patch_job and response.status_code == 202:
             updated_details = self._handle_response(202, u'deployment asset patch', response)
 
             ret202 = True
 
-            print("Since ASSET is patched, deployment with new asset id/rev is being started. " \
+            print(f"Since {patch_job_field} is patched, deployment with new asset id/rev is being started. " \
                   "Monitor the status using deployments.get_details(deployment_uid) api")
-        elif 'hardware_spec' in changes:
+        elif response.status_code == 202:
             updated_details = self._handle_response(202, u'deployment scaling', response)
             ret202 = True
         else:
