@@ -69,7 +69,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
     desc: str, optional
         Description
 
-    test_size: float, optional
+    holdout_size: float, optional
         Percentage of the entire dataset to leave as a holdout. Default 0.1
 
     max_num_daub_ensembles: int, optional
@@ -81,7 +81,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
     train_sample_rows_test_size: float, optional
         Training data sampling percentage
 
-    daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
+    include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
         List of estimators to include in computation process.
 
     cognito_transform_names: List['Transformers'], optional
@@ -104,10 +104,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
                  prediction_column: str,
                  scoring: 'Metrics',
                  desc: str = None,
-                 test_size: float = 0.1,
+                 holdout_size: float = 0.1,
                  max_num_daub_ensembles: int = 1,
                  train_sample_rows_test_size: float = 1.,
-                 daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
                  cognito_transform_names: List['Transformers'] = None,
                  positive_label: str = None,
                  _data_clients: List[Tuple['DataConnection', 'resource']] = None,
@@ -153,10 +153,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'prediction_type': prediction_type,
                 'prediction_column': prediction_column,
                 'scoring': scoring,
-                'test_size': test_size,
+                'holdout_size': holdout_size,
                 'max_num_daub_ensembles': int(max_num_daub_ensembles),
                 'train_sample_rows_test_size': train_sample_rows_test_size,
-                'daub_include_only_estimators': daub_include_only_estimators,
+                'include_only_estimators': include_only_estimators,
                 'cognito_transform_names': cognito_transform_names,
                 'positive_label': positive_label
             }
@@ -175,7 +175,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'prediction_type': prediction_type,
                 'prediction_column': prediction_column,
                 'scoring': scoring,
-                'test_size': test_size,
+                'holdout_size': holdout_size,
                 'max_num_daub_ensembles': max_num_daub_ensembles
             }
 
@@ -200,10 +200,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'prediction_type': 'classification',
                 'prediction_column': 'y',
                 'scoring': 'roc_auc',
-                'test_size': 0.1,
+                'holdout_size': 0.1,
                 'max_num_daub_ensembles': 1,
                 'train_sample_rows_test_size': 0.8,
-                'daub_include_only_estimators': ["ExtraTreesClassifierEstimator",
+                'include_only_estimators': ["ExtraTreesClassifierEstimator",
                                                 "GradientBoostingClassifierEstimator",
                                                 "LGBMClassifierEstimator",
                                                 "LogisticRegressionEstimator",
