@@ -20,7 +20,7 @@ from numpy import ndarray
 from pandas import DataFrame
 
 from ibm_watson_machine_learning.helpers.connections import (
-    DataConnection, S3Location, FSLocation, AssetLocation, WSDAssetLocation)
+    DataConnection, S3Location, FSLocation, AssetLocation, WSDAssetLocation, ContainerLocation)
 from ibm_watson_machine_learning.preprocessing import DataJoinPipeline
 from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes)
@@ -28,7 +28,7 @@ from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
     ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset)
-from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
+from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale, all_logging_disabled
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
 from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, \
@@ -314,8 +314,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         # note: check if DataJoinGraph node names are correct and equivalent
         # to training DataConnections IDs/data_join_node_names
         if self.params['data_join_graph']:
-            if any(filter(lambda x: x.type == DataConnectionTypes.CA, training_data_reference)):
+            # note: If the location does not have path attribute it is either S3Location or DatabaseLocation
+            if any(filter(lambda x: x.type == DataConnectionTypes.CA and hasattr(x.location, "path"), training_data_reference)):
                 raise OBMForNFSIsNotSupported()
+            # --- end note
 
             data_join_graph = self.params['data_join_graph']
             data_connection_ids = [connection.id for connection in training_data_reference]
@@ -354,11 +356,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
 
         # note: if user did not provide results storage information, use default ones
         if training_results_reference is None:
-            if isinstance(training_data_reference[0].location, S3Location):
+            if isinstance(training_data_reference[0].location, S3Location) and not self._workspace.wml_client.ICP:
                 training_results_reference = DataConnection(
                     connection=training_data_reference[0].connection,
                     location=S3Location(bucket=training_data_reference[0].location.bucket,
-                                        path='.')
+                                        path=".")
                 )
 
             elif isinstance(training_data_reference[0].location, AssetLocation) and not self._workspace.wml_client.ICP:
@@ -376,6 +378,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                         path="default_autoai_out")
                 )
 
+            elif isinstance(training_data_reference[0].location, ContainerLocation) and not self._workspace.wml_client.ICP:
+                training_results_reference = DataConnection(location=ContainerLocation(path="default_autoai_out"))
+
             else:
                 location = FSLocation()
                 if self._workspace.WMLS:
@@ -402,7 +407,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 raise InvalidDataAsset(reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
 
         # note: results can be stored only on FS or COS
-        if not isinstance(training_results_reference.location, (S3Location, FSLocation, AssetLocation)):
+        if not isinstance(training_results_reference.location, (S3Location, FSLocation, AssetLocation, ContainerLocation)):
             raise TypeError('Unsupported results location type. Results referance can be stored'
                             ' only on S3Location or FSLocation or AssetLocation.')
         # -- end
@@ -604,25 +609,26 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             if check_lale:
                 try_import_lale()
             from lale.helpers import import_from_sklearn_pipeline
-            # note: join preprocessing step to final pipeline (enables wider visualization and pretty print)
-            try:
-                import numpy as np
-                preprocessing_object = self.get_preprocessing_pipeline()
-                preprocessing_pipeline = preprocessing_object.lale_pipeline
+            with all_logging_disabled():
+                # note: join preprocessing step to final pipeline (enables wider visualization and pretty print)
+                try:
+                    import numpy as np
+                    preprocessing_object = self.get_preprocessing_pipeline()
+                    preprocessing_pipeline = preprocessing_object.lale_pipeline
 
-                # note: fake fit for preprocessing pipeline to be able to predict
-                preprocessing_pipeline = preprocessing_pipeline.fit(np.array([[1, 2, 3], [2, 3, 4]]), np.array([1, 2]))
-                return preprocessing_pipeline >> import_from_sklearn_pipeline(pipeline_model)
+                    # note: fake fit for preprocessing pipeline to be able to predict
+                    preprocessing_pipeline = preprocessing_pipeline.fit(np.array([[1, 2, 3], [2, 3, 4]]), np.array([1, 2]))
+                    return preprocessing_pipeline >> import_from_sklearn_pipeline(pipeline_model)
 
-            except MissingDataPreprocessingStep:
-                return import_from_sklearn_pipeline(pipeline_model)
+                except MissingDataPreprocessingStep:
+                    return import_from_sklearn_pipeline(pipeline_model)
 
-            except BaseException as e:
-                message = f"Cannot load preprocessing step. Error: {e}"
-                print(message)
-                warn(message)
-                return import_from_sklearn_pipeline(pipeline_model)
-            # --- end note
+                except BaseException as e:
+                    message = f"Cannot load preprocessing step. Error: {e}"
+                    print(message)
+                    warn(message)
+                    return import_from_sklearn_pipeline(pipeline_model)
+                # --- end note
 
         else:
             raise ValueError('Incorrect value of \'astype\'. '
@@ -721,7 +727,15 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             details = self._engine._wml_client.training.get_details(
                 training_uid=self._engine._current_run_id)
 
-            path = f"{details['entity']['results_reference']['location']['path']}/{self._engine._current_run_id}/data/obm/features/part"
+            path = details['entity']['results_reference']['location'].get(
+                'path',
+                details['entity']['results_reference']['location'].get('file_name'))
+
+            if path == '':
+                path = f"{self._engine._current_run_id}/data/obm/features/part"
+
+            else:
+                path = f"{path}/{self._engine._current_run_id}/data/obm/features/part"
 
             results_connection = DataConnection._from_dict(_dict=details['entity']['results_reference'])
             results_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
