@@ -134,7 +134,7 @@ class Functions(WMLResource):
                 defaults = args_spec.defaults if args_spec.defaults is not None else []
                 args = args_spec.args if args_spec.args is not None else []
 
-                if function.__name__ is 'score':
+                if function.__name__ == 'score':
                     code = '\n'.join(code)
                     file_content = code
                 elif len(args) == len(defaults):
@@ -457,7 +457,7 @@ score = {}()
                 defaults = args_spec.defaults if args_spec.defaults is not None else []
                 args = args_spec.args if args_spec.args is not None else []
 
-                if function.__name__ is 'score':
+                if function.__name__ == 'score':
                     code = '\n'.join(code)
                     file_content = code
                 elif len(args) == len(defaults):
