@@ -92,6 +92,9 @@ class BaseDataConnection(ABC):
     def _download_obm_data_from_cos(self, cos_client: 'resource') -> 'DataFrame':
         """Download preprocessed OBM data. COS version."""
 
+        if '//' in self._obm_cos_path:  # sometimes there is an additional slash, need to replace it
+            self._obm_cos_path = self._obm_cos_path.replace('//', '/')
+
         # note: fetch all OBM file part names
         cos_summary = cos_client.Bucket(self.location.bucket).objects.filter(Prefix=self._obm_cos_path)
         file_names = [file_name.key for file_name in cos_summary]
@@ -132,9 +135,12 @@ class BaseDataConnection(ABC):
         """Download json file."""
         json_content = {}
 
+        if '//' in path:  # sometimes there is an additional slash, need to replace it
+            path = path.replace('//', '/')
+
         # TODO: remove S3 implementation
         if self.type == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
             cos_client = self._init_cos_client()
 
@@ -213,7 +219,8 @@ class BaseDataConnection(ABC):
                         if 'connection_id' not in attachment_details:
                             return False
 
-                        connection_details = self._wml_client.connections.get_details(attachment_details['connection_id'])
+                        connection_details = self._wml_client.connections.get_details(
+                            attachment_details['connection_id'])
 
                     else:
                         raise WMLClientError("Failed while downloading the attachment " + attachment_id)
@@ -222,10 +229,18 @@ class BaseDataConnection(ABC):
                     try:
                         from project_lib import Project
                         project = Project.access()
+
+                        # note: Check if asset is located directly in the project files
+                        #       If yes it is not a connected data.
+                        #       [Prevents unnecessary logging].
+                        if any(file['asset_id'] == _id for file in project.get_files()):
+                            return False
+                        # --- end note
+
                         try:
                             connection_details = project.get_connected_data(_id)
 
-                        except RuntimeError:    # when data asset is normal not s3 or database
+                        except RuntimeError:  # when data asset is normal not s3 or database
                             return False
 
                         attachment_details = {'connection_path': connection_details.get('datapath')}
@@ -246,6 +261,85 @@ class BaseDataConnection(ABC):
                     except ModuleNotFoundError:
                         raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
 
+            elif self.type == 'container':
+                if self._wml_client is not None:
+                    if self._wml_client.default_space_id is not None:
+                        details = self._wml_client.spaces.get_details(self._wml_client.default_space_id)
+
+                    else:
+                        project_url = self._wml_client.service_instance._href_definitions.get_project_href(
+                            self._wml_client.default_project_id)
+                        if self._wml_client.ICP:
+                            response = requests.get(
+                                project_url,
+                                headers=self._wml_client._get_headers(),
+                                verify=False
+                            )
+
+                        else:
+                            response = requests.get(
+                                    project_url,
+                                    headers=self._wml_client._get_headers()
+                                )
+
+                        details = response.json()
+
+                    properties = details['entity']['storage']['properties']
+                    properties.update(details['entity']['storage']['properties']['credentials']['editor'])
+                    properties['url'] = properties['endpoint_url']
+                    properties['access_key'] = properties.get('access_key_id')
+                    properties['secret_key'] = properties.get('secret_access_key')
+
+                    connection_details = {
+                        'entity': {
+                            'datasource_type': 'bluemixcloudobjectstorage',
+                            'properties': properties
+                        }
+                    }
+
+                else:
+                    try:
+                        from project_lib import Project
+                        token = os.environ.get('USER_ACCESS_TOKEN')
+
+                        if token is None:
+                            raise NotImplementedError(
+                                f"""To succesfully read the training data used in AutoAI experiment, you need to provide the project token.
+                            **To insert the project token to your notebook:**
+                                Click the More icon on your notebook toolbar and then click Insert project token.
+                                Run the inserted code cell.
+                            Note:
+                            If you are told in a message that no project token exists, click the link in the message to be redirected to the project's Settings page where you can create a project token.
+                            **To create a project token:**
+                                Click New token in the Access tokens section on the Settings page of your project.
+                                Enter a name, select Editor role for the project, and create a token.
+                                Go back to your notebook, click the More icon on the notebook toolbar and then click Insert project token.
+                                Run the inserted code cell."""
+                            )
+
+                        token = token.split('Bearer ')[-1]
+
+                        _project = Project(project_id=os.environ.get('PROJECT_ID'),
+                                           project_access_token=token)
+
+                        details = _project.get_storage_metadata()
+
+                        properties = details['properties']
+                        properties.update(properties['credentials']['editor'])
+                        properties['url'] = properties['endpoint_url']
+                        properties['access_key'] = properties.get('access_key_id')
+                        properties['secret_key'] = properties.get('secret_access_key')
+
+                        connection_details = {
+                            'entity': {
+                                'datasource_type': 'bluemixcloudobjectstorage',
+                                'properties': properties
+                            }
+                        }
+
+                    except ModuleNotFoundError:
+                        raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+
             elif self.type == 's3' or self.type == 'fs':
                 return False
 
@@ -254,15 +348,22 @@ class BaseDataConnection(ABC):
 
             # Note: Check with project libs if connection points to S3
             if self._wml_client is not None:
-                if (connection_details['entity']['datasource_type'] ==
-                        self._wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage') or
-                        connection_details['entity']['datasource_type'] == 'bluemixcloudobjectstorage'):
+                datasource_type = connection_details['entity']['datasource_type']
+                datasource_type_id_ibm_cos = self._wml_client.connections.get_datasource_type_uid_by_name(
+                    'bluemixcloudobjectstorage')
+                datasource_type_id_aws_cos = self._wml_client.connections.get_datasource_type_uid_by_name(
+                    'cloudobjectstorage')
 
+                if (datasource_type == datasource_type_id_ibm_cos or datasource_type == datasource_type_id_aws_cos or
+                        datasource_type == 'bluemixcloudobjectstorage' or datasource_type == 'cloudobjectstorage'):
                     cos_type = True
 
                 else:
                     cos_type = False
 
+            elif self.type == 'container':
+                cos_type = True
+
             elif 'url' in connection_details:
                 cos_type = True
                 connection_details['entity'] = {'properties': connection_details}
@@ -275,7 +376,8 @@ class BaseDataConnection(ABC):
                 if 'cos_hmac_keys' in str(connection_details['entity']['properties']):
                     creds = json.loads(connection_details['entity']['properties']['credentials'])
                     connection_details['entity']['properties']['access_key'] = creds['cos_hmac_keys']['access_key_id']
-                    connection_details['entity']['properties']['secret_key'] = creds['cos_hmac_keys']['secret_access_key']
+                    connection_details['entity']['properties']['secret_key'] = creds['cos_hmac_keys'][
+                        'secret_access_key']
 
                 if self.connection is None:
                     from .connections import S3Connection
@@ -290,6 +392,9 @@ class BaseDataConnection(ABC):
                     self.connection.access_key_id = connection_details['entity']['properties'].get('access_key')
                     self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
 
+                if self.type == 'container':
+                    self.location.bucket = connection_details['entity']['properties']['bucket_name']
+
                 if self.type == 'data_asset':
                     try:
                         self.location.bucket = attachment_details['connection_path'].split('/')[1]
@@ -309,7 +414,7 @@ class BaseDataConnection(ABC):
                 raise e
 
             else:
-                return False    # if we are in WS, ignore this check even if there was some error
+                return False  # if we are in WS, ignore this check even if there was some error
 
     def _download_indices_from_cos(self, cos_client: 'resource', location_path) -> 'DataFrame':
         """Download indices for this connection. COS version"""
@@ -323,21 +428,21 @@ class BaseDataConnection(ABC):
 
         buffer = io.BytesIO(file['Body'].read())
         data = try_load_tar_gz(buffer=buffer,
-                                separator=self.auto_pipeline_params.get('csv_separator', ','),
-                                encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
-                                )
+                               separator=self.auto_pipeline_params.get('csv_separator', ','),
+                               encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                               )
 
         return data
 
     def _download_data_from_cos(self, cos_client: 'resource') -> 'DataFrame':
         """Download training data for this connection. COS version"""
-
+        location = self.location.file_name if hasattr(self.location, "file_name") else self.location.path
         try:
             file = cos_client.Object(self.location.bucket,
-                                     self.location.path).get()
+                                     location).get()
         except:
             file = list(cos_client.Bucket(self.location.bucket).objects.filter(
-                Prefix=self.location.path))[0].get()
+                Prefix=location))[0].get()
 
         buffer = io.BytesIO(file['Body'].read())
         data = try_load_dataset(buffer=buffer,
@@ -357,10 +462,11 @@ class BaseDataConnection(ABC):
             asset_id = self.location.href.split('?')[0].split('/')[-1]
 
             # note: download data asset details
-            asset_response = requests.get(self._wml_client.service_instance._href_definitions.get_data_asset_href(asset_id),
-                                          params=self._wml_client._params(),
-                                          headers=self._wml_client._get_headers(),
-                                          verify=False)
+            asset_response = requests.get(
+                self._wml_client.service_instance._href_definitions.get_data_asset_href(asset_id),
+                params=self._wml_client._params(),
+                headers=self._wml_client._get_headers(),
+                verify=False)
 
             asset_details = self._wml_client.data_assets._handle_response(200, u'get assets', asset_response)
 
@@ -369,8 +475,9 @@ class BaseDataConnection(ABC):
                 attachment_url = asset_details['attachments'][0]['handle']['key']
 
                 # note: make the whole url pointing out the csv
-                artifact_content_url = (f"{self._wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}"
-                                        f"{attachment_url}")
+                artifact_content_url = (
+                    f"{self._wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}"
+                    f"{attachment_url}")
 
                 # note: stream the whole CSV file
                 csv_response = requests.get(artifact_content_url,
@@ -487,9 +594,9 @@ class BaseDataConnection(ABC):
         except (ApiRequestFailure, AttributeError):
             with open(location_path, 'rb') as data_buffer:
                 data = try_load_tar_gz(buffer=data_buffer,
-                                        separator=self.auto_pipeline_params.get('csv_separator', ','),
-                                        encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
-                                        )
+                                       separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                       encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                       )
 
         return data
 
