@@ -27,7 +27,8 @@ __all__ = [
     "NFSConnection",
     "NFSLocation",
     'ConnectionAssetLocation',
-    "DatabaseLocation"
+    "DatabaseLocation",
+    "ContainerLocation"
 ]
 
 import io
@@ -49,6 +50,7 @@ from ibm_watson_machine_learning.utils.autoai.errors import (
     HoldoutSplitNotSupported, InvalidCOSCredentials, MissingLocalAsset, InvalidIdType, NotWSDEnvironment,
     NotExistingCOSResource, InvalidDataAsset, CannotReadSavedRemoteDataBeforeFit
 )
+from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure
 from .base_connection import BaseConnection
@@ -95,7 +97,8 @@ class DataConnection(BaseDataConnection):
                                  'NFSLocation',
                                  'DeploymentOutputAssetLocation',
                                  'ConnectionAssetLocation',
-                                 'DatabaseLocation'] = None,
+                                 'DatabaseLocation',
+                                 'ContainerLocation'] = None,
                  connection: Optional[Union['S3Connection', 'NFSConnection', 'ConnectionAsset']] = None,
                  data_join_node_name: Union[str, List[str]] = None,
                  data_asset_id: str = None,
@@ -135,17 +138,25 @@ class DataConnection(BaseDataConnection):
 
         elif isinstance(connection, ConnectionAsset):
             self.type = DataConnectionTypes.CA
+            # note: We expect a `file_name` keyword for CA pointing to COS.
+            if isinstance(self.location, S3Location):
+                self.location.file_name = self.location.path
+                del self.location.path
+            # --- end note
 
         elif isinstance(location, FSLocation):
             self.type = DataConnectionTypes.FS
 
+        elif isinstance(location, ContainerLocation):
+            self.type = DataConnectionTypes.CN
+
         elif isinstance(location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation,
                                    WSDAssetLocation, DeploymentOutputAssetLocation)):
             self.type = DataConnectionTypes.DS
 
         self.auto_pipeline_params = {}  # note: needed parameters for recreation of autoai holdout split
         self._wml_client = None
-        self.__wml_client = None    # only for getter/setter for AssetLocation href
+        self.__wml_client = None  # only for getter/setter for AssetLocation href
         self._run_id = None
         self._obm = False
         self._obm_cos_path = None
@@ -154,8 +165,8 @@ class DataConnection(BaseDataConnection):
         if data_join_node_name is None:
             # TODO: remove S3 implementation
             if self.type == DataConnectionTypes.S3 or (
-                    self.type == DataConnectionTypes.CA and hasattr(location, 'path')):
-                self.id = location.path
+                    self.type == DataConnectionTypes.CA and hasattr(location, 'file_name')):
+                self.id = location.get_location()
 
             else:
                 self.id = None
@@ -174,6 +185,7 @@ class DataConnection(BaseDataConnection):
         self.__wml_client = var
         if isinstance(self.location, (AssetLocation, WSDAssetLocation)):
             self.location.wml_client = self.__wml_client
+
     # --- end note
 
     @classmethod
@@ -260,7 +272,6 @@ class DataConnection(BaseDataConnection):
 
         if self.connection is not None:
             _dict['connection'] = deepcopy(self.connection.to_dict())
-
         else:
             _dict['connection'] = {}
 
@@ -294,7 +305,7 @@ class DataConnection(BaseDataConnection):
         """
         # TODO: remove S3 implementation
         if _dict['type'] == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
             data_connection: 'DataConnection' = cls(
                 connection=S3Connection(
@@ -312,12 +323,12 @@ class DataConnection(BaseDataConnection):
                 location=FSLocation._set_path(path=_dict['location']['path'])
             )
         elif _dict['type'] == DataConnectionTypes.CA:
-            if _dict['location'].get('path') and _dict['location'].get('bucket'):
+            if _dict['location'].get('file_name') is not None and _dict['location'].get('bucket'):
                 data_connection: 'DataConnection' = cls(
                     connection_asset_id=_dict['connection']['id'],
                     location=S3Location(
                         bucket=_dict['location']['bucket'],
-                        path=_dict['location']['path']
+                        path=_dict['location']['file_name']
                     )
                 )
 
@@ -333,6 +344,11 @@ class DataConnection(BaseDataConnection):
                     connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
                     location=NFSLocation(path=_dict['location']['path'])
                 )
+        elif _dict['type'] == DataConnectionTypes.CN:
+            data_connection: 'DataConnection' = cls(
+                location=ContainerLocation(path=_dict['location']['path'])
+            )
+
         else:
             data_connection: 'DataConnection' = cls(
                 location=AssetLocation._set_path(href=_dict['location']['href'])
@@ -346,20 +362,23 @@ class DataConnection(BaseDataConnection):
     def read_indices(self, **kwargs):
         training_details = self._wml_client.training.get_details(self.auto_pipeline_params['run_id'])
         # TODO indices location should be read from response, than constructed
-        #holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['holdout_data_indices_location']
-        holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['schema_location']
-        holdout_data_indices_location = '/'.join(holdout_data_indices_location.split('/')[:-3]) + '/holdout_data_indices.tar.gz'
+        # holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['holdout_data_indices_location']
+        holdout_data_indices_location = \
+        training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['schema_location']
+        holdout_data_indices_location = '/'.join(
+            holdout_data_indices_location.split('/')[:-3]) + '/holdout_data_indices.tar.gz'
 
         data = DataFrame()
 
         # TODO: Remove S3 implementation
         if self.type == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
             cos_client = self._init_cos_client()
 
             try:
-                data = self._download_indices_from_cos(cos_client=cos_client, location_path=holdout_data_indices_location)
+                data = self._download_indices_from_cos(cos_client=cos_client,
+                                                       location_path=holdout_data_indices_location)
 
             except Exception as cos_access_exception:
                 raise ConnectionError(
@@ -370,11 +389,12 @@ class DataConnection(BaseDataConnection):
             try:
                 if self._check_if_connection_asset_is_s3():
                     cos_client = self._init_cos_client()
-                    data = self._download_indices_from_cos(cos_client=cos_client, location_path=holdout_data_indices_location)
+                    data = self._download_indices_from_cos(cos_client=cos_client,
+                                                           location_path=holdout_data_indices_location)
                 else:
                     # TODO Prepare actual solution
                     raise Exception('Not supported yet')
-                    #data = self._download_training_data_from_data_asset_storage()
+                    # data = self._download_training_data_from_data_asset_storage()
 
             except NotImplementedError as e:
                 raise e
@@ -401,13 +421,13 @@ class DataConnection(BaseDataConnection):
 
             data = self._download_indices_from_file_system(location_path=holdout_data_indices_location)
 
-        elif self.type == DataConnectionTypes.CA:
-
+        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
             if self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
-                    data = self._download_indices_from_cos(cos_client=cos_client, location_path=holdout_data_indices_location)
+                    data = self._download_indices_from_cos(cos_client=cos_client,
+                                                           location_path=holdout_data_indices_location)
 
                 except Exception as cos_access_exception:
                     raise ConnectionError(
@@ -484,8 +504,8 @@ class DataConnection(BaseDataConnection):
             try:
                 indices = self.read_indices()
             except Exception as e:
-                print("\"with_holdout_split\" option is depreciated.")
-                warn("\"with_holdout_split\" option is depreciated.")
+                print("\"with_holdout_split\" option is deprecated.")
+                warn("\"with_holdout_split\" option is deprecated.")
 
         from sklearn.model_selection import train_test_split
 
@@ -508,7 +528,7 @@ class DataConnection(BaseDataConnection):
 
         # TODO: Remove S3 implementation
         if self.type == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
             cos_client = self._init_cos_client()
 
@@ -530,11 +550,12 @@ class DataConnection(BaseDataConnection):
                 raise NotImplementedError("Multiple files for CP4D / WML Server is not yet supported.")
 
             try:
-                if self._check_if_connection_asset_is_s3():
-                    cos_client = self._init_cos_client()
-                    data = self._download_data_from_cos(cos_client=cos_client)
-                else:
-                    data = self._download_training_data_from_data_asset_storage()
+                with all_logging_disabled():
+                    if self._check_if_connection_asset_is_s3():
+                        cos_client = self._init_cos_client()
+                        data = self._download_data_from_cos(cos_client=cos_client)
+                    else:
+                        data = self._download_training_data_from_data_asset_storage()
 
             except NotImplementedError as e:
                 raise e
@@ -564,43 +585,44 @@ class DataConnection(BaseDataConnection):
             else:
                 data = self._download_training_data_from_file_system()
 
-        elif self.type == DataConnectionTypes.CA:
+        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
+            with all_logging_disabled():
+                if self._check_if_connection_asset_is_s3():
+                    cos_client = self._init_cos_client()
 
-            if self._check_if_connection_asset_is_s3():
-                cos_client = self._init_cos_client()
+                    try:
+                        if self._obm:
+                            data = self._download_obm_data_from_cos(cos_client=cos_client)
 
-                try:
-                    if self._obm:
-                        data = self._download_obm_data_from_cos(cos_client=cos_client)
+                        else:
+                            data = self._download_data_from_cos(cos_client=cos_client)
 
-                    else:
-                        data = self._download_data_from_cos(cos_client=cos_client)
+                    except Exception as cos_access_exception:
+                        raise ConnectionError(
+                            f"Unable to access data object in cloud object storage with credentials supplied. "
+                            f"Error: {cos_access_exception}")
+                else:
+                    try:
+                        data = self._download_data_from_nfs_connection()
 
-                except Exception as cos_access_exception:
-                    raise ConnectionError(f"Unable to access data object in cloud object storage with credentials supplied. "
-                                          f"Error: {cos_access_exception}")
-            else:
-                try:
-                    data = self._download_data_from_nfs_connection()
+                    except Exception:
+                        try_import_pyarrow()
 
-                except Exception:
-                    try_import_pyarrow()
+                        flight_service = FlightService(
+                            wml_client=self._wml_client,
+                            params=self.auto_pipeline_params,
+                            data_location={'location': self.location.to_dict(),
+                                           'type': self.type,
+                                           "connection": self.connection.to_dict()},
+                            experiment_metadata=kwargs.get('experiment_metadata')
+                        )
 
-                    flight_service = FlightService(
-                        wml_client=self._wml_client,
-                        params=self.auto_pipeline_params,
-                        data_location={'location': self.location.to_dict(),
-                                       'type': self.type,
-                                       "connection": self.connection.to_dict()},
-                        experiment_metadata=kwargs.get('experiment_metadata')
-                    )
-
-                    data = flight_service.read()
+                        data = flight_service.read()
 
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
 
-        # note: this code is depreciated, user information isa provided at the beginning.
+        # note: this code is deprecated, user information isa provided at the beginning.
         if with_holdout_split:
             if not isinstance(data, DataFrame):
                 raise HoldoutSplitNotSupported(
@@ -630,10 +652,13 @@ class DataConnection(BaseDataConnection):
                     random_state=33,
                     stratify=data[self.auto_pipeline_params['prediction_column']].values if is_classification else None)
             else:
-                x_holdout = data.iloc[indices.values.flatten()].drop(self.auto_pipeline_params['prediction_column'], axis=1)
+                x_holdout = data.iloc[indices.values.flatten()].drop(self.auto_pipeline_params['prediction_column'],
+                                                                     axis=1)
                 y_holdout = data.iloc[indices.values.flatten()][self.auto_pipeline_params['prediction_column']].values
-                x = data.loc[set(data.index) - set(indices.values.flatten())].drop(self.auto_pipeline_params['prediction_column'], axis=1)
-                y = data.loc[set(data.index) - set(indices.values.flatten())][self.auto_pipeline_params['prediction_column']].values
+                x = data.loc[set(data.index) - set(indices.values.flatten())].drop(
+                    self.auto_pipeline_params['prediction_column'], axis=1)
+                y = data.loc[set(data.index) - set(indices.values.flatten())][
+                    self.auto_pipeline_params['prediction_column']].values
 
             data_train = DataFrame(data=x, columns=data.columns.tolist())
             data_train[self.auto_pipeline_params['prediction_column']] = y
@@ -660,7 +685,7 @@ class DataConnection(BaseDataConnection):
         """
         # TODO: Remove S3 implementation
         if self.type == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
             if remote_name is None:
                 raise MissingValue('remote_name')
 
@@ -683,7 +708,7 @@ class DataConnection(BaseDataConnection):
             else:
                 raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
 
-        elif self.type == DataConnectionTypes.CA:
+        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
             if self._check_if_connection_asset_is_s3():
                 cos_resource_client = self._init_cos_client()
                 if isinstance(data, str):
@@ -788,8 +813,7 @@ class S3Connection(BaseConnection):
 
     def __init__(self, endpoint_url: str, access_key_id: str = None, secret_access_key: str = None,
                  api_key: str = None, service_name: str = None, auth_endpoint: str = None) -> None:
-
-        warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+        warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
         if (access_key_id is None or secret_access_key is None) and (api_key is None or auth_endpoint is None):
             raise InvalidCOSCredentials(reason='You need to specify (access_key_id and secret_access_key) or'
@@ -824,7 +848,7 @@ class S3Location(BaseLocation):
         COS bucket name
 
     path: str, required
-        COS data path in the bucket
+        COS data path in the bucket.
 
     model_location: str, optional
         Path to the pipeline model in the COS.
@@ -850,6 +874,50 @@ class S3Location(BaseLocation):
             size = 0
         return size
 
+    def get_location(self) -> str:
+        if hasattr(self, "file_name"):
+            return self.file_name
+        else:
+            return self.path
+
+
+class ContainerLocation(BaseLocation):
+    """
+    Connection class to default COS in user Project/Space.
+    """
+
+    def __init__(self, path: Optional[str] = None, **kwargs) -> None:
+        if path is None:
+            self.path = "/{option}/{id}" + f"/assets/auto_ml/auto_ml.{uuid.uuid4()}/wml_data"
+
+        else:
+            self.path = path
+
+        self.bucket = None
+
+        if kwargs.get('model_location') is not None:
+            self._model_location = kwargs['model_location']
+
+        if kwargs.get('training_status') is not None:
+            self._training_status = kwargs['training_status']
+
+    def to_dict(self) -> dict:
+        _dict = super().to_dict()
+
+        if 'bucket' in _dict and _dict['bucket'] is None:
+            del _dict['bucket']
+
+        return _dict
+
+    @classmethod
+    def _set_path(cls, path: str) -> 'ContainerLocation':
+        location = cls()
+        location.path = path
+        return location
+
+    def _get_file_size(self):
+        pass
+
 
 class FSLocation(BaseLocation):
     """
@@ -1153,7 +1221,6 @@ class ConnectionAsset(BaseConnection):
 
     def __init__(self, connection_id: str):
         self.id = connection_id
-        self.asset_id = connection_id
 
 
 class NFSConnection(BaseConnection):
@@ -1393,4 +1460,3 @@ class DatabaseLocation(BaseLocation):
 
     def _get_file_size(self) -> None:
         raise NotImplementedError()
-
