@@ -156,7 +156,7 @@ VOLUME_SERVICE_FILE_UPLOAD = u'{}/zen-volumes/{}/v1/volumes/files/'
 PROMOTE_ASSET = u'{}/projects/api/rest/catalogs/assets/{}/promote'
 
 DATAPLATFORM_URLS_MAP = {
-            'https://wml-fvt.ml.test.cloud.ibm.com': 'https://api.dataplatform.dev.cloud.ibm.com',
+            'https://wml-fvt.ml.test.cloud.ibm.com': 'https://dataplatform.dev.cloud.ibm.com',
             'https://yp-qa.ml.cloud.ibm.com': 'https://dataplatform.test.cloud.ibm.com',
             'https://private.yp-qa.ml.cloud.ibm.com': 'https://dataplatform.test.cloud.ibm.com',
             'https://yp-cr.ml.cloud.ibm.com': 'https://dataplatform.test.cloud.ibm.com',
@@ -495,11 +495,17 @@ class HrefDefinitions:
             data_platform_url = DATAPLATFORM_URLS_MAP[self._wml_credentials['url']]
             return PROMOTE_ASSET.format(data_platform_url, asset_id)
         else:
-            return PROMOTE_ASSET.format(self._wml_credentials['url'], asset_id)
+            promote_href = PROMOTE_ASSET.format(self._wml_credentials['url'], asset_id)
+            try:
+                # note: For CPD older than 4.0 we need to roll back to older endpoint.
+                if float(self._wml_credentials.get("version")) < 4.0:
+                    promote_href = promote_href.replace("/projects", "")
+                # --- end note
+            finally:
+                return promote_href
 
     # def get_envs_href(self):
     #     return DEPLOYMENT_ENVS_HREF_PATTERN.format(self._wml_credentials['url'])
     #
     # def get_env_href(self, env_id):
     #     return DEPLOYMENT_ENV_HREF_PATTERN.format(self._wml_credentials['url'],env_id)
-
