@@ -76,7 +76,7 @@ class MLRepositoryApi(RepositoryApi):
 
 
         if 'DEPLOYMENT_PLATFORM' in os.environ and os.environ['DEPLOYMENT_PLATFORM'] == 'private':
-            r = requests.put('{}/v4/models/{}/content'.format(
+            r = requests.put('{}/ml/v4/models/{}/content'.format(
                 self.api_client.repository_path,
                 model_id
 
@@ -89,7 +89,7 @@ class MLRepositoryApi(RepositoryApi):
             if (r.status_code != 200 and r.status_code !=202):
                 raise ApiException(r.status_code, r.text)
         else:
-            r = requests.put('{}/v4/models/{}/content'.format(
+            r = requests.put('{}/ml/v4/models/{}/content'.format(
                 self.api_client.repository_path,
                 model_id
 
@@ -103,7 +103,7 @@ class MLRepositoryApi(RepositoryApi):
                 verify=True
                 if 'DEPLOYMENT_PLATFORM' in os.environ and os.environ['DEPLOYMENT_PLATFORM'] == 'private':
                     verify=False
-                r = requests.delete('{}/v4/models/{}'.format(
+                r = requests.delete('{}/ml/v4/models/{}'.format(
                     self.api_client.repository_path,
                     model_id
                 ),
