@@ -206,7 +206,6 @@ class ModelCollection:
             raise ValueError('Invalid type for artifact_id: {}'.format(artifact_id.__class__.__name__))
 
         return self.repository_api.v3_ml_assets_models_artifact_id_delete(artifact_id)
-        return self.repository_api.v3_ml_assets_models_artifact_id_delete(artifact_id)
 
     def save(self, artifact, query_param=None):
 
@@ -512,39 +511,8 @@ class ModelCollection:
         return self.client.pipelines.save(pipeline_artifact)
 
     def _create_pipeline_model(self, model_artifact, query_param=None):
-        if query_param is not None and 'version' in query_param:
-            model_artifact = self._create_pipeline_model_v4_cloud(model_artifact, query_param)
-            return model_artifact
-        else:
-            model_input = self._prepare_model_input(model_artifact)
-            model_output = self.repository_api.ml_assets_model_creation(model_input)
-            if model_output is not None:
-                location = model_output.metadata.href
-                if location is not None:
-                    logger.debug('New pipeline model created at: {}'.format(location))
-                    matched = re.search('.*/v4/models/([A-Za-z0-9\-]+)', location)
-                    model_id = model_output.metadata.guid
-                    #               martifact = model_artifact._copy(uid=model_id)
-                    new_artifact = ModelAdapter(model_output, location, self.client).artifact()
-                    new_artifact.load_model = lambda: model_artifact.ml_pipeline_model
-
-                    new_artifact.model_instance = lambda: model_artifact.ml_pipeline_model
-                    model_artifact_with_version = model_artifact._copy(meta_props=new_artifact.meta,uid=model_id)
-                    if MetaNames.IMPORT not in model_artifact_with_version.meta.get():
-                        status_url = self._upload_pipeline_model_content(model_artifact_with_version, query_param)
-                        #this is for async
-                        if status_url is not None and status_url != "":
-                            place_holder =model_artifact_with_version.meta.add(MetaNames.STATUS_URL, status_url)
-                            new_async_artifact = model_artifact_with_version._copy(meta_props=place_holder)
-                            return new_async_artifact
-                        else:
-                            return new_artifact
-
-                    else:
-                        return model_artifact_with_version
-            else:
-                logger.info('Location of the new pipeline model not found')
-                raise ApiException(404, 'No artifact location')
+        model_artifact = self._create_pipeline_model_v4_cloud(model_artifact, query_param)
+        return model_artifact
 
     def _create_pipeline_model_version(self, model_artifact, query_param=None):
         model_version_input = self._get_version_input(model_artifact)
@@ -650,7 +618,7 @@ class ModelCollection:
             raise ValueError("Request with url ='%s'failed" %url)
 
     @staticmethod
-    def _prepare_model_input(artifact, v4_cloud=None):
+    def _prepare_model_input(artifact):
         meta = artifact.meta
         runtime = artifact.meta.prop(MetaNames.RUNTIME_UID)
 
@@ -658,12 +626,10 @@ class ModelCollection:
 
         framework_runtimes = artifact.meta.prop(MetaNames.FRAMEWORK_RUNTIMES)
 
-        frlibraries = artifact.meta.prop(MetaNames.FRAMEWORK_LIBRARIES)
         hyperparameters = artifact.meta.prop(MetaNames.HYPER_PARAMETERS)
         output_data_schema = artifact.meta.prop(MetaNames.OUTPUT_DATA_SCHEMA)
         runtime_input = artifact.meta.prop(MetaNames.RUNTIMES.URL)
         type_model = artifact.meta.prop(MetaNames.TYPE)
-        domain = artifact.meta.prop(MetaNames.DOMAIN)
         space = artifact.meta.prop(MetaNames.SPACE_UID)
         project= None
         if artifact.meta.prop(MetaNames.PROJECT_UID) is not None:
@@ -673,26 +639,15 @@ class ModelCollection:
         training_lib = artifact.meta.prop(MetaNames.TRAINING_LIB_UID)
         model_definition = artifact.meta.prop(MetaNames.MODEL_DEFINITON)
 
-        import_location = artifact.meta.prop(MetaNames.IMPORT)
-        input_schema = artifact.meta.prop(MetaNames.INPUT_DATA_SCHEMA)
-        output_schema = artifact.meta.prop(MetaNames.OUTPUT_DATA_SCHEMA)
         model_input_evaluation =  artifact.meta.prop(MetaNames.EVALUATION_METHOD)
         import_location =  artifact.meta.prop(MetaNames.IMPORT)
-        category = artifact.meta.prop(MetaNames.CATEGORY)
         custom = artifact.meta.prop(MetaNames.CUSTOM)
         metrics = artifact.meta.prop(MetaNames.METRICS)
         size = artifact.meta.prop(MetaNames.SIZE)
         software_spec = artifact.meta.prop(MetaNames.SOFTWARE_SPEC)
-        space_id = None
-        if artifact.meta.prop(MetaNames.SPACE_ID) is not None:
-            space_id = artifact.meta.prop(MetaNames.SPACE_ID)
-        project_id = None
-        if artifact.meta.prop(MetaNames.PROJECT_ID) is not None:
-            project_id = artifact.meta.prop(MetaNames.PROJECT_ID)
 
         description = artifact.meta.prop(MetaNames.DESCRIPTION)
         transformed_label = artifact.meta.prop(MetaNames.TRANSFORMED_LABEL_FIELD)
-        label_column = artifact.meta.prop(MetaNames.LABEL_FIELD)
         training_data_list = None
         if artifact.meta.prop(MetaNames.TRAINING_DATA_REFERENCES) is not None:
             dataref_list = artifact.meta.prop(MetaNames.TRAINING_DATA_REFERENCES)
@@ -701,8 +656,7 @@ class ModelCollection:
                 i=1
                 for iter1 in dataref_list:
                     training_ref_obj = iter1
-                    name = training_ref_obj.get('name', None)
-                    type = training_ref_obj.get('type', None)
+                    type_ = training_ref_obj.get('type', None)
                     connection = training_ref_obj.get('connection', None)
                     location = training_ref_obj.get('location', None)
                     schema = training_ref_obj.get('schema', None)
@@ -711,16 +665,13 @@ class ModelCollection:
                         training_schema["id"] = "1"
                         schema = training_schema
 
-                    if v4_cloud:
-                        training_ref = {"id": training_ref_obj.get('id', i),
-                                        "type": type,
-                                        "connection": connection,
-                                        "location": location,
-                                        "schema": schema
-                                        }
-                        i = i + 1
-                    else:
-                        training_ref = ModelContentLocation(name, type, connection, location, schema)
+                    training_ref = {"id": training_ref_obj.get('id', i),
+                                    "type": type_,
+                                    "connection": connection,
+                                    "location": location,
+                                    "schema": schema
+                                    }
+                    i = i + 1
 
                     training_data_list.append(training_ref)
         else:
@@ -730,44 +681,27 @@ class ModelCollection:
                 training_data_ref_obj["id"]="1"
                 import os
                 if "DEPLOYMENT_PLATFORM" in os.environ and os.environ["DEPLOYMENT_PLATFORM"] == "private":
-                    type = "fs"
+                    type_ = "fs"
                 else:
-                    type = "s3"
+                    type_ = "s3"
+
+                training_data_ref = {
+                    "id": "1",
+                    "type": type_,
+                    "connection": {"endpoint_url": "not_applicable",
+                     "access_key_id": "not_applicable",
+                     "secret_access_key": "not_applicable"},
+                    "location": {},
+                    "schema": training_data_ref_obj
+                }
 
-                if v4_cloud:
-                    training_data_ref = {
-                        "id": "1",
-                        "type": type,
-                        "connection": {"endpoint_url": "not_applicable",
-                         "access_key_id": "not_applicable",
-                         "secret_access_key": "not_applicable"},
-                        "location": {},
-                        "schema": training_data_ref_obj
-                    }
-                else:
-                    training_data_ref = ModelContentLocation(
-                        None,
-                        type,
-                        {"endpoint_url": "not_applicable",
-                         "access_key_id": "not_applicable",
-                         "secret_access_key": "not_applicable"},
-                        {
-                            "bucket": "not_applicable"
-                        },
-                        training_data_ref_obj
-                    )
                 training_data_list.append(training_data_ref)
 
         if artifact.meta.prop(MetaNames.SPACE_UID) is not None:
             spaceobj=artifact.meta.prop(MetaNames.SPACE_UID)
-            if v4_cloud:
-                space = SpaceModels(
-                    spaceobj.get('id', None)
-                )
-            else:
-                space = SpaceModels(
-                    spaceobj.get('href',None)
-                    )
+            space = SpaceModels(
+                spaceobj.get('id', None)
+            )
         if artifact.meta.prop(MetaNames.SIZE) is not None:
             sizeobj=artifact.meta.prop(MetaNames.SIZE)
             size = ModelsSize(
@@ -777,10 +711,7 @@ class ModelCollection:
 
         if artifact.meta.prop(MetaNames.PIPELINE_UID) is not None:
             pipelineobj=artifact.meta.prop(MetaNames.PIPELINE_UID)
-            if v4_cloud:
-                pipeline = PipelinesModels(id=pipelineobj.get('id', None))
-            else:
-                pipeline = PipelinesModels(href=pipelineobj.get('href', None))
+            pipeline = PipelinesModels(href=pipelineobj.get('href'), id=pipelineobj.get('id'))
         if artifact.meta.prop(MetaNames.MODEL_DEFINITON) is not None:
             model_definition_obj = artifact.meta.prop(MetaNames.MODEL_DEFINITON)
             model_definition = ModelDefinitionModels(
@@ -795,8 +726,8 @@ class ModelCollection:
             importobj=artifact.meta.prop(MetaNames.IMPORT)
             import_location = ModelContentLocation(
                 importobj.get('name', None),
-                importobj.get('type',None),
-                importobj.get('connection',None),
+                importobj.get('type', None),
+                importobj.get('connection', None),
                 importobj.get('location', None)
             )
         schemas=None
@@ -843,7 +774,7 @@ class ModelCollection:
                 runtimes = json.loads(artifact.meta.prop(MetaNames.RUNTIMES))
             else:
                 runtimes = artifact.meta.prop(MetaNames.RUNTIMES)
-            if not issubclass (type(runtimes), list):
+            if not issubclass(type(runtimes), list):
                 raise ValueError('Invalid data format for runtimes.')
 
         if framework_runtimes is not None and software_spec is None:
@@ -851,15 +782,9 @@ class ModelCollection:
                 framework_runtimes = json.loads(artifact.meta.prop(MetaNames.FRAMEWORK_RUNTIMES))
             else:
                 framework_runtimes = artifact.meta.prop(MetaNames.FRAMEWORK_RUNTIMES)
-            if not issubclass (type(framework_runtimes), list):
+            if not issubclass(type(framework_runtimes), list):
                 raise ValueError('Invalid data format for framework_runtimes.')
 
-        run_frmRun = None
-        if framework_runtimes is not None:
-            run_frmRun = framework_runtimes
-        elif runtimes is not None:
-            run_frmRun = runtimes
-
         hyper_param_list = None
         if isinstance(hyperparameters, str):
             hyper_param_list = []
@@ -1220,7 +1145,7 @@ class ModelCollection:
             raise e
 
     def _create_pipeline_model_v4_cloud(self, model_artifact, query_param=None):
-        model_input = self._prepare_model_input(model_artifact, v4_cloud=True)
+        model_input = self._prepare_model_input(model_artifact)
         headers = self.client.api_client.default_headers
 
         model_output = self.repository_api.ml_assets_model_creation_v4_cloud(model_input, query_param,headers)
