@@ -1,7 +1,7 @@
 import unittest
 import sys
 import io
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.tests.Cloud.preparation_and_cleaning import *
 
 
@@ -17,7 +17,7 @@ class TestWMLClientCloudWithExperiment(unittest.TestCase):
     trained_model_id = None
     experiment_id = None
     experiment_run_id = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
