@@ -157,7 +157,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
         else:  # for cloud and COS
             connection_details = self.wml_client.connections.create({
-                'datasource_type': 'bluemixcloudobjectstorage',
+                'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage'),
                 'name': 'Connection to COS for tests',
                 'properties': {
                     'bucket': self.bucket_name,
