@@ -64,6 +64,7 @@ class TestAutoAIRemote(unittest.TestCase):
         bucket_name = "wml-autoaitests-qa"
 
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_cos_path = 'data/credit_risk_training_light.csv'
     cos_resource_instance_id = None
@@ -76,8 +77,6 @@ class TestAutoAIRemote(unittest.TestCase):
     OPTIMIZER_NAME = 'CreditRisk binary as sample notebook test'
     DEPLOYMENT_NAME = "CreditRisk AutoAI test Deployment "
 
-    space_name = 'autoai_tests_sdk_space'
-
     space_id = None
     project_id = None
 
