@@ -9,7 +9,6 @@ from ibm_watson_machine_learning.tests.autoai.svt.abstract_test_iris_wml_autoai_
     AbstractTestAutoAIRemote)
 
 
-@unittest.skip("Not ready, training does not support connection_asset")
 @unittest.skipIf(is_cp4d(), "Supported only on CLOUD")
 class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
     """
@@ -44,13 +43,13 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
 
     def test_00c_prepare_connection_to_COS(self):
         connection_details = self.wml_client.connections.create({
-            'datasource_type': 'bluemixcloudobjectstorage',
+            'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage'),
             'name': 'Connection to COS for tests',
             'properties': {
                 'bucket': self.bucket_name,
                 'access_key': self.cos_credentials['cos_hmac_keys']['access_key_id'],
                 'secret_key': self.cos_credentials['cos_hmac_keys']['secret_access_key'],
-                'iam_url': self.cos_credentials['iam_url'],
+                'iam_url': self.wml_client.service_instance._href_definitions.get_iam_token_url(),
                 'url': self.cos_endpoint
             }
         })
