@@ -68,13 +68,12 @@ class TestAutoAIRemote(unittest.TestCase):
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_cos_path = 'data/iris_dataset_different_delimeter.csv'
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'autoai_tests_sdk_space'
-
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
     DEPLOYMENT_NAME = "Iris AutoAI Deployment tests"
 
@@ -358,22 +357,22 @@ class TestAutoAIRemote(unittest.TestCase):
         print(predictions)
         self.assertGreater(len(predictions), 0, msg="Empty predictions")
 
-    def test_18_get_random_historical_optimizer_and_its_pipeline(self):
-        run_params = self.experiment.runs(filter=self.OPTIMIZER_NAME).get_params(run_id=self.random_run_id)
-        self.assertIn('prediction_type', run_params,
-                      msg="prediction_type field not fount in run_params. Run_params are: {}".format(run_params))
-        historical_opt = self.experiment.runs.get_optimizer(self.random_run_id)
-        self.assertIsInstance(historical_opt, RemoteAutoPipelines,
-                              msg="historical_optimizer is not type RemoteAutoPipelines. It's type of {}".format(
-                                  type(historical_opt)))
-        summary = self.historical_opt.summary()
-
-        self.assertGreater(len(summary), 0, msg=f"No pipelines found for optimizer with run_id = {self.random_run_id},"
-                                                f" and parameters: {run_params}")
-        pipeline_name = summary.index.values[0]
-        pipeline = historical_opt.get_pipeline(pipeline_name, self.experiment.PipelineTypes.SKLEARN)
-        print(type(pipeline))
-        self.assertIsInstance(pipeline, Pipeline)
+    # def test_18_get_random_historical_optimizer_and_its_pipeline(self):
+    #     run_params = self.experiment.runs(filter=self.OPTIMIZER_NAME).get_params(run_id=self.random_run_id)
+    #     self.assertIn('prediction_type', run_params,
+    #                   msg="prediction_type field not fount in run_params. Run_params are: {}".format(run_params))
+    #     historical_opt = self.experiment.runs.get_optimizer(self.random_run_id)
+    #     self.assertIsInstance(historical_opt, RemoteAutoPipelines,
+    #                           msg="historical_optimizer is not type RemoteAutoPipelines. It's type of {}".format(
+    #                               type(historical_opt)))
+    #     summary = self.historical_opt.summary()
+    #
+    #     self.assertGreater(len(summary), 0, msg=f"No pipelines found for optimizer with run_id = {self.random_run_id},"
+    #                                             f" and parameters: {run_params}")
+    #     pipeline_name = summary.index.values[0]
+    #     pipeline = historical_opt.get_pipeline(pipeline_name, self.experiment.PipelineTypes.SKLEARN)
+    #     print(type(pipeline))
+    #     self.assertIsInstance(pipeline, Pipeline)
 
     #################################
     #      DEPLOYMENT SECTION       #
