@@ -78,7 +78,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     prediction_column = "Reviewer_Score"
     text_columns = ['Negative_Review', 'Positive_Review']
-    word2vec_feature_number = 20
+    word2vec_feature_number = 5
 
     with_text_transformer = True
 
@@ -174,17 +174,27 @@ class TestAutoAIRemote(unittest.TestCase):
     #     self.assertGreater(len(data), 0)
 
     def test_03_initialize_optimizer(self):
+
+        if is_cp4d():
+            #snap estimators are not available for CPD
+            estimators = [self.experiment.RegressionAlgorithms.LR,
+                          self.experiment.RegressionAlgorithms.EX_TREES,
+                          self.experiment.RegressionAlgorithms.RIDGE]
+
+        else:
+            estimators = [self.experiment.RegressionAlgorithms.LR,
+                          self.experiment.RegressionAlgorithms.EX_TREES,
+                          self.experiment.RegressionAlgorithms.SnapBM]
+
         TestAutoAIRemote.remote_auto_pipelines = self.experiment.optimizer(
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.REGRESSION,
-            include_only_estimators=[self.experiment.RegressionAlgorithms.LR,
-                                     self.experiment.RegressionAlgorithms.EX_TREES,
-                                     self.experiment.RegressionAlgorithms.SnapBM],
+            include_only_estimators=estimators,
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
             text_processing=self.with_text_transformer,
-            text_columns_names=self.text_columns,
+            # text_columns_names=self.text_columns,
             word2vec_feature_number=self.word2vec_feature_number,
             autoai_pod_version=self.pod_version
         )
@@ -238,16 +248,16 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(feature_importance_df)
         str_feature_importance_index_list = str(list(feature_importance_df.sort_index().index))
 
-        for column in self.text_columns:
-            self.assertIn(f'word2vec({column})', str(str_feature_importance_index_list),
-                          msg=f"word2vec({column}) is not in features importance table."
-                              f" Full features list: {str_feature_importance_index_list}")
-
-        self.assertIn('NewTextFeature_0',str_feature_importance_index_list,
-                      msg="Text features were numerated incorrectly.")
-        self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
-                      str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
-
+        # TODO: Uncomment when support text columns
+        # for column in self.text_columns:
+        #     self.assertIn(f'word2vec({column})', str(str_feature_importance_index_list),
+        #                   msg=f"word2vec({column}) is not in features importance table."
+        #                       f" Full features list: {str_feature_importance_index_list}")
+        #
+        # self.assertIn('NewTextFeature_0',str_feature_importance_index_list,
+        #               msg="Text features were numerated incorrectly.")
+        # self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
+        #               str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
 
     def test_08b_get_metrics(self):
         self.wml_client.training.get_metrics(self.run_id)
@@ -280,7 +290,7 @@ class TestAutoAIRemote(unittest.TestCase):
     ########
 
     def test_14__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
-        TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
+        TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_6')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
         from lale.operators import TrainablePipeline
