@@ -71,7 +71,7 @@ class TestAutoAIRemote(unittest.TestCase):
     X_values = None
     y_values = None
     elapsed_time = None
-    size_dataset = environ.get('SIZE_DATASET_MB', "10")
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_location = './autoai/data/donorchoose_1MB.csv'
 
@@ -85,7 +85,19 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'tests_sdk_space_text_transformer'
+    train_sample_columns_index_list = [1, 2, 4, 5, 7,  8, 9]
+    text_processing = True
+    word2vec_feature_number = 15
+    drop_duplicates = True
+
+    def _check_optimizer_parameters(self, parameters):
+        # check_pipeline_parameters:
+        self.assertIsNotNone(parameters.get('name'))
+
+        self.assertEqual(parameters.get('prediction_column'), self.prediction_column)
+        self.assertEqual(parameters.get('text_processing'), self.text_processing)
+        self.assertEqual(parameters.get('drop_duplicates'), self.drop_duplicates)
+        self.assertEqual(parameters.get('word2vec_feature_number'), self.word2vec_feature_number)
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -177,7 +189,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.LOG_LOSS,
-            train_sample_columns_index_list=[4.0, 5.0, 9.0],
+            train_sample_columns_index_list=self.train_sample_columns_index_list,
             text_processing=True,
             word2vec_feature_number=15,
             autoai_pod_version=self.pod_version
@@ -189,6 +201,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_04_get_configuration_parameters_of_remote_auto_pipeline(self):
         parameters = self.remote_auto_pipelines.get_params()
         print(parameters)
+        self._check_optimizer_parameters(parameters)
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
     def test_05_fit_run_training_of_auto_ai_in_wml(self):
@@ -245,14 +258,20 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsInstance(data_connections[0], DataConnection,
                               msg="There should be a DataConnection object returned")
 
-    def test_12_get_pipeline_params_specific_pipeline_parameters(self):
+    def test_12a_get_pipeline_params_specific_pipeline_parameters(self):
         pipeline_params = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1')
         print(pipeline_params)
 
-    def test_13__get_pipeline_params__fetch_best_pipeline_parameters__parameters_fetched_as_dict(self):
+    def test_12a_get_pipeline_params__fetch_best_pipeline_parameters__parameters_fetched_as_dict(self):
         best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
         print(best_pipeline_params)
 
+    def test_13_check_params_of_realoaded_pipeline_optimizer(self):
+        historical_optimizer = self.experiment.runs.get_optimizer(self.run_id)
+        hist_opt_params = historical_optimizer.get_params()
+        print(hist_opt_params)
+        self._check_optimizer_parameters(hist_opt_params)
+
     ####
     # LALE #
     ########
