@@ -202,7 +202,7 @@ class TestAutoAIRemote(unittest.TestCase):
             autoai_pod_version=self.pod_version,
             t_shirt_size=TShirtSize.L,
             # train_sample_columns_index_list = [1,2,3,5],
-            text_columns_names=self.text_columns
+            # text_columns_names=self.text_columns
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
