@@ -7,10 +7,6 @@ from base_class_V4test_online_deployment import TestBaseOnlineDeployment
 class TestAIFunction(TestBase, TestBaseOnlineDeployment, unittest.TestCase):
     deployment_name = "ai_function_deployment"
     model_name = "ai_function_model"
-    scoring_payload = [{
-        "fields": ["multiplication"],
-        "values": [[2.0, 2.0], [99.0, 99.0]]
-    }]
     function_filepath = os.path.join(os.getcwd(), 'svt', 'artifacts', 'ai_function.gz')
     sw_spec_name_cloud = 'default_py3.7'
     sw_spec_name_icp = 'default_py3.7_opence'
@@ -28,12 +24,11 @@ class TestAIFunction(TestBase, TestBaseOnlineDeployment, unittest.TestCase):
 
         return self.wml_client.repository.get_function_uid(ai_function_details)
 
-    def patch_model(self):
-        function_props = {
-            self.wml_client.repository.FunctionMetaNames.DESCRIPTION: 'desc',
-        }
-
-        details = self.wml_client.repository.update_function(TestAIFunction.model_uid, function_props)
+    def get_scoring_payload(self):
+        return [{
+            "fields": ["multiplication"],
+            "values": [[2.0, 2.0], [99.0, 99.0]]
+        }]
 
 
 if __name__ == '__main__':
