@@ -95,7 +95,7 @@ def create_spark_mllib_model_data():
         .format('org.apache.spark.sql.execution.datasources.csv.CSVFileFormat') \
         .option('header', 'true') \
         .option('inferSchema', 'true') \
-        .load("svt/artifacts/GoSales_Tx_NaiveBayes.csv")
+        .load("Cloud/artifacts/GoSales_Tx_NaiveBayes.csv")
 
     splitted_data = df_data.randomSplit([0.8, 0.18, 0.02], 24)
     train_data = splitted_data[0]
