@@ -2,7 +2,7 @@ import unittest
 import time
 import io
 import sys
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.experiments import Experiments
 from preparation_and_cleaning import *
 
@@ -18,7 +18,7 @@ class TestWMLClientWithKeras(unittest.TestCase):
     trained_model_uid = None
     train_run_id = None
     scoring_url = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
