@@ -44,7 +44,8 @@ __all__ = [
     'get_sw_spec_and_type_based_on_sklearn',
     'validate_additional_params_for_optimizer',
     'is_list_composed_from_enum',
-    'validate_optimizer_enum_values'
+    'validate_optimizer_enum_values',
+    'all_logging_disabled'
 ]
 
 import io
@@ -60,6 +61,8 @@ from tarfile import open as open_tar
 from typing import Dict, Union, Tuple, List, TYPE_CHECKING, Optional, Any
 from warnings import warn
 from zipfile import ZipFile
+from contextlib import contextmanager
+import logging
 from collections.abc import Sequence
 
 import pkg_resources
@@ -68,7 +71,7 @@ from packaging import version
 
 from .enums import (RegressionAlgorithms, RegressionAlgorithmsCP4D, ClassificationAlgorithms,
                     ClassificationAlgorithmsCP4D, ForecastingAlgorithms, ForecastingAlgorithmsCP4D, Transformers,
-                    Metrics, TShirtSize, PredictionType)
+                    Metrics, TShirtSize, PredictionType, DataConnectionTypes)
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
                      VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics)
@@ -335,8 +338,8 @@ def load_file_from_file_system(wml_client: 'APIClient',
 
 
 def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
-                               file_path: str,
-                               stream: bool = True) -> 'io.BytesIO':
+                                         file_path: str,
+                                         stream: bool = True) -> 'io.BytesIO':
     """
     Load file into memory from the file system.
 
@@ -382,6 +385,7 @@ def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
 
     return buffer
 
+
 class NextRunDetailsGenerator:
     """
     Generator class to produce next list of run details.
@@ -548,7 +552,14 @@ def prepare_auto_ai_model_to_publish_notebook(pipeline_model: Union['Pipeline',
     temp_model_name = '__temp_model.pickle'
 
     # note: path to the json describing the autoai POD specification
-    path = result_connection.location._model_location.split('model.pickle')[0]
+    path_parts = result_connection.location._model_location.split('model.pickle')
+    if len(path_parts) == 1:
+        path = result_connection.location._model_location.split('model.zip')[0]
+        path = f"{path}pre_hpo_d_output/Pipeline1/"
+
+    else:
+        path = result_connection.location._model_location.split('model.pickle')[0]
+
     pipeline_model_json_path = f"{path}pipeline-model.json"
     schema_path = f"{path}schema.json"
 
@@ -605,7 +616,8 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
         run_params: dict,
         run_id: str,
         wml_client: 'APIClient',
-        space_id: str) -> Union[Tuple[str, Dict[str, dict]]]:
+        space_id: str,
+        result_reference: 'DataConnection' = None) -> Union[Tuple[str, Dict[str, dict]]]:
     """
     Helper function to specify `content_location` statement for AutoAI models to store in repository.
 
@@ -624,12 +636,15 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
 
     space_id: str, required
 
+    result_reference: DataConnection, optional
+        Needed when we have something different than old S3 on a Cloud.
+
     Returns
     -------
     If cp4d: Dictionary with model schema and artifact name to upload, stored temporally in the user local file system.
     else: path name to the stored model in COS
     """
-    request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client)
+    request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client, result_reference)
     # note: fill connection details
     if 'connection' in run_params['entity']['results_reference']:
         request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
@@ -776,6 +791,22 @@ def init_cos_client(connection: dict) -> 'resource':
     from ibm_botocore.client import Config
     from ibm_boto3 import resource
 
+    # note: In case of connection_asset we need too get COS credentials from connection details.
+    if connection.get("properties") is not None:
+        if "access_key" in connection["properties"] and "secret_key" in connection["properties"]:
+            connection = {
+                "endpoint_url": connection["properties"].get("url"),
+                "access_key_id": connection["properties"].get("access_key"),
+                "secret_access_key": connection["properties"].get("secret_key"),
+            }
+        else:
+            connection = {
+                "endpoint_url": connection["properties"].get("url"),
+                "api_key": connection["properties"].get("api_key"),
+                "auth_endpoint": connection["properties"].get("iam_url")
+            }
+    # --- end note
+
     if connection.get('auth_endpoint') is not None and connection.get('api_key') is not None:
         cos_client = resource(
             service_name='s3',
@@ -784,7 +815,6 @@ def init_cos_client(connection: dict) -> 'resource':
             config=Config(signature_version="oauth"),
             endpoint_url=connection['endpoint_url']
         )
-
     else:
         cos_client = resource(
             service_name='s3',
@@ -1067,6 +1097,7 @@ def try_load_tar_gz(
         os.remove(tmp_file)
         os.remove('holdout_data_indices.csv')
 
+
 def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: str) -> bool:
     """
     Check packages installed versions and inform the user about needed ones.
@@ -1116,7 +1147,8 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                     if version.parse(installed_module_version) < version.parse(package['version']):
                         # we should produce different error for lale and snap_ml as only 2 major numbers are significant
                         packages_less_strict_error_list = ['lale', 'snapml'],
-                        if package['name'] in packages_less_strict_error_list and len(package['version'].split('.')) >= 3:
+                        if package['name'] in packages_less_strict_error_list and len(
+                                package['version'].split('.')) >= 3:
                             _version = package['version'].split('.')[:2]  # take only 3 major version number
                             _version[-1] = 'x'
                             package['version'] = '.'.join(_version)
@@ -1232,23 +1264,29 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
         if is_ml_metrics:
             return details['entity']['status'].get('metrics', [{}])[0].get('ml_metrics', {}).keys()
         elif is_ts_metrics:
-            names = list(['validation_' + x for x in details['entity']['status'].get('metrics', [{}])[0].get('ts_metrics', {}).get('training',{}).keys()])
+            names = list(['validation_' + x for x in
+                          details['entity']['status'].get('metrics', [{}])[0].get('ts_metrics', {}).get('training',
+                                                                                                        {}).keys()])
             try:
-                holdout_names = list(['holdout_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'holdout' in x['ts_metrics']][0]['ts_metrics']['holdout'].keys()])
+                holdout_names = list(['holdout_' + y for y in
+                                      [x for x in details['entity']['status'].get('metrics', [{}]) if
+                                       'holdout' in x['ts_metrics']][0]['ts_metrics']['holdout'].keys()])
             except IndexError:
                 holdout_names = []
             try:
-                backtest_names = list(['backtest_' + y for y in [x for x in details['entity']['status'].get('metrics', [{}]) if 'backtest' in x['ts_metrics']][0]['ts_metrics']['backtest']['avg'].keys()])
+                backtest_names = list(['backtest_' + y for y in
+                                       [x for x in details['entity']['status'].get('metrics', [{}]) if
+                                        'backtest' in x['ts_metrics']][0]['ts_metrics']['backtest']['avg'].keys()])
             except IndexError:
                 backtest_names = []
 
-
             return names + holdout_names + backtest_names
 
-    def is_winner(pipeline_name): # ts only
+    def is_winner(pipeline_name):  # ts only
         if is_ts_metrics:
             return len(list([x for x in details['entity']['status'].get('metrics', [{}])
-                  if x['context']['intermediate_model']['name'] == pipeline_name and 'holdout' in x['ts_metrics']])) > 0
+                             if x['context']['intermediate_model']['name'] == pipeline_name and 'holdout' in x[
+                                 'ts_metrics']])) > 0
         elif is_ml_metrics:
             return True
 
@@ -1288,14 +1326,18 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
                 elif is_ts_metrics:
                     def prepare_items(metrics, pipeline_name, metric_name, prefix):
                         try:
-                            chosen_obj = [x for x in metrics if x['context']['intermediate_model']['name'] == pipeline_name and metric_name in x['ts_metrics']][0]
+                            chosen_obj = [x for x in metrics if
+                                          x['context']['intermediate_model']['name'] == pipeline_name and metric_name in
+                                          x['ts_metrics']][0]
                         except Exception as e:
                             return []
 
                         if metric_name == 'backtest':
-                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name]['avg'][x] for x in chosen_obj['ts_metrics'][metric_name]['avg']}.items())
+                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name]['avg'][x] for x in
+                                         chosen_obj['ts_metrics'][metric_name]['avg']}.items())
                         else:
-                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name][x] for x in chosen_obj['ts_metrics'][metric_name]}.items())
+                            return list({prefix + x: chosen_obj['ts_metrics'][metric_name][x] for x in
+                                         chosen_obj['ts_metrics'][metric_name]}.items())
 
                     pipeline_name = pipeline['context']['intermediate_model']['name']
                     metrics = details['entity']['status'].get('metrics', [])
@@ -1422,7 +1464,14 @@ def download_wml_pipeline_details_from_file(result_client_and_connection: Tuple[
     """Try to download wml pipeline details from user COS."""
 
     try:
-        path = result_client_and_connection[0].location._model_location.split('model.pickle')[0]
+        path_parts = result_client_and_connection[0].location._model_location.split('model.pickle')
+        if len(path_parts) == 1:
+            path = result_client_and_connection[0].location._model_location.split('model.zip')[0]
+            path = f"{path}pre_hpo_d_output/Pipeline1/"
+
+        else:
+            path = result_client_and_connection[0].location._model_location.split('model.pickle')[0]
+
         path = f"{path}pipeline-model.json"
 
         file = result_client_and_connection[1].Object(
@@ -1529,7 +1578,8 @@ def validate_additional_params_for_optimizer(params):
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
         'enabled_feature_engineering_as_json', 'fairness_info', 'text_processing', 'word2vec_feature_number',
-        '_enable_snapml_estimators','return_holdout_indices', 'retrain_pipelines_on_holdout_data', 'retrain_on_holdout',
+        '_enable_snapml_estimators', 'return_holdout_indices', 'retrain_pipelines_on_holdout_data',
+        'retrain_on_holdout',
         'sampling_type', 'n_parallel_data_connections', 'calculate_data_metrics',
         'batch_size', 'metrics_on_logical_batch', 'logical_batch_size', 'text_columns_names'
     ]
@@ -1539,7 +1589,7 @@ def validate_additional_params_for_optimizer(params):
             raise AdditionalParameterIsUnexpected(k)
 
 
-def download_request_json(run_params: dict, model_name: str, wml_client) -> dict:
+def download_request_json(run_params: dict, model_name: str, wml_client, results_reference: 'DataConnection' = None) -> dict:
     run_id = run_params['metadata']['id']
     is_ml_metrics = 'ml_metrics' in run_params['entity']['status'].get('metrics')[-1]
     is_ts_metrics = 'ts_metrics' in run_params['entity']['status'].get('metrics')[-1]
@@ -1565,8 +1615,24 @@ def download_request_json(run_params: dict, model_name: str, wml_client) -> dict
             request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
 
     else:
-        cos_client = init_cos_client(run_params['entity']['results_reference']['connection'])
-        bucket = run_params['entity']['results_reference']['location']['bucket']
+        # Note: container type needs to be converted to S3 type to handle credentials!
+        bucket = None
+        if results_reference is not None:
+            results_reference._check_if_connection_asset_is_s3()
+            bucket = results_reference.location.bucket  # bucket is removed when casting to dict for Container type
+            results_reference = results_reference._to_dict()
+
+        else:
+            results_reference = run_params['entity']['results_reference']
+        # --- end note
+
+        if results_reference['type'] == DataConnectionTypes.CA:
+            connection_details = wml_client.connections.get_details(results_reference['connection']['id'])['entity']
+            cos_client = init_cos_client(connection_details)
+        else:
+            cos_client = init_cos_client(results_reference['connection'])
+
+        bucket = bucket if bucket is not None else results_reference['location']['bucket']
         cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
         with open('request.json', 'r') as f:
             request_str = f.read()
@@ -1608,7 +1674,7 @@ def is_list_composed_from_enum(sequence: List[Union[str, enum.Enum]],
         else:
             attributes = inspect.getmembers(enum_class, lambda attr: not (inspect.isroutine(attr)))
             enum_values = [attr_val for attr_name, attr_val in attributes
-                           if not(attr_name.startswith('__') and attr_name.endswith('__'))]
+                           if not (attr_name.startswith('__') and attr_name.endswith('__'))]
 
         for el in sequence:
             el_value = el.value if isinstance(el, enum.Enum) else el
@@ -1623,12 +1689,12 @@ def validate_optimizer_enum_values(
                                                  RegressionAlgorithms,
                                                  ForecastingAlgorithms]],
         include_only_estimators: List[Union[ClassificationAlgorithms,
-                                                 RegressionAlgorithms,
-                                                 ForecastingAlgorithms]],
+                                            RegressionAlgorithms,
+                                            ForecastingAlgorithms]],
         cognito_transform_names: List[Transformers],
         scoring: str,
         t_shirt_size: str,
-        is_cpd = False) -> None:
+        is_cpd=False) -> None:
     """
     Validate if passed optimizer variables takes values from defined enums.
 
@@ -1699,3 +1765,27 @@ def fallback_to_pip_for_version_check(package: dict) -> str:
 
     except Exception:
         raise pkg_resources.DistributionNotFound()
+
+
+@contextmanager
+def all_logging_disabled(highest_level=logging.CRITICAL):
+    """
+    A context manager that will prevent any logging messages
+    triggered during the body from being processed.
+    :param highest_level: the maximum logging level in use.
+      This would only need to be changed if a custom level greater than CRITICAL
+      is defined.
+    """
+    # two kind-of hacks here:
+    #    * can't get the highest logging level in effect => delegate to the user
+    #    * can't get the current module-level override => use an undocumented
+    #       (but non-private!) interface
+
+    previous_level = logging.root.manager.disable
+
+    logging.disable(highest_level)
+
+    try:
+        yield
+    finally:
+        logging.disable(previous_level)
