@@ -97,7 +97,7 @@ class WrongEnvironmentVersion(WMLClientError, ValueError):
 
 
 class CannotAutogenerateBedrockUrl(WMLClientError, ValueError):
-    def __init__(self):
+    def __init__(self, e1, e2):
         WMLClientError.__init__(self, "Attempt of generating `bedrock_url` automatically failed. "
                                       "If iamintegration=True, please provide `bedrock_url` in wml_credentials. "
-                                      "If iamintegration=False, please validate your credentials.")
\ No newline at end of file
+                                      "If iamintegration=False, please validate your credentials.", reason=[e1, e2])
\ No newline at end of file
