@@ -60,6 +60,10 @@ class Party:
         import_source(ibmfl_module_location )
         from ibmfl.party.party import Party
         self.Party = Party(**kwargs)
+        self.connection = self.Party.connection
 
     def start(self):
-        self.Party.start()
\ No newline at end of file
+        self.Party.start()
+
+    def isStopped(self):
+        return self.Party.connection.stopped
\ No newline at end of file
